Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1361)

Unified Diff: runtime/vm/port.cc

Issue 1130753006: Hide Isolate pointer from embedder (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/port.h ('k') | runtime/vm/service_isolate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/port.cc
diff --git a/runtime/vm/port.cc b/runtime/vm/port.cc
index 5a7506852cfe941ece58c05bc03907f0e7813704..efb55f305af4d6459a7c776d19d51fec1a544f7c 100644
--- a/runtime/vm/port.cc
+++ b/runtime/vm/port.cc
@@ -25,14 +25,14 @@ Random* PortMap::prng_ = NULL;
intptr_t PortMap::FindPort(Dart_Port port) {
// ILLEGAL_PORT (0) is used as a sentinel value in Entry.port. The loop below
// could return the index to a deleted port when we are searching for
// port id ILLEGAL_PORT. Return -1 immediately to indicate the port
// does not exist.
- if (port == ILLEGAL_PORT) {
+ if (port == DART_ILLEGAL_PORT) {
return -1;
}
- ASSERT(port != ILLEGAL_PORT);
+ ASSERT(port != DART_ILLEGAL_PORT);
intptr_t index = port % capacity_;
intptr_t start_index = index;
Entry entry = map_[index];
@@ -25,14 +25,14 @@ Random* PortMap::prng_ = NULL;
intptr_t PortMap::FindPort(Dart_Port port) {
- // ILLEGAL_PORT (0) is used as a sentinel value in Entry.port. The loop below
- // could return the index to a deleted port when we are searching for
- // port id ILLEGAL_PORT. Return -1 immediately to indicate the port
+ // DART_ILLEGAL_PORT (0) is used as a sentinel value in Entry.port. The loop
+ // below could return the index to a deleted port when we are searching for
+ // port id DART_ILLEGAL_PORT. Return -1 immediately to indicate the port
// does not exist.
« no previous file with comments | « runtime/vm/port.h ('k') | runtime/vm/service_isolate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698